@@ -107,3 +107,12 @@ rbindl <- function(x) {
                                                 use.names = TRUE))
   xx
 }
+
+assert <- function(x, y) {
+  if (!is.null(x)) {
+    if (!inherits(x, y)) {
+      stop(deparse(substitute(x)), " must be of class ",
+        paste0(y, collapse = ", "), call. = FALSE)
+    }
+  }
+}
