@@ -20,7 +20,6 @@ test_that("has_coords works with all data sources as planned", {
 
   aa <- occ('Accipiter striatus', from = 'gbif', limit = 5, has_coords = TRUE)
   bb <- occ('Accipiter striatus', from = 'ecoengine', limit = 5, has_coords = TRUE)
-  cc <- occ('linepithema humile', from = 'antweb', limit = 5, has_coords = TRUE)
   dd <- occ('Accipiter striatus', from = 'inat', limit = 5, has_coords = TRUE)
   ee <- occ('Accipiter striatus', from = 'idigbio', limit = 5, has_coords = TRUE)
   ff <- occ('Accipiter striatus', from = 'vertnet', limit = 5, has_coords = TRUE)
@@ -30,7 +29,7 @@ test_that("has_coords works with all data sources as planned", {
 
   expect_is(aa, "occdat")
   expect_is(bb, "occdat")
-  expect_is(cc, "occdat")
+  # expect_is(cc, "occdat")
   expect_is(dd, "occdat")
   expect_is(ee, "occdat")
   expect_is(ff, "occdat")
@@ -43,9 +42,6 @@ test_that("has_coords works with all data sources as planned", {
   expect_false(anyNA(bb$ecoengine$data[[1]]$longitude))
   expect_false(anyNA(bb$ecoengine$data[[1]]$latitude))
 
-  expect_false(anyNA(cc$antweb$data[[1]]$longitude))
-  expect_false(anyNA(cc$antweb$data[[1]]$latitude))
-
   expect_false(anyNA(dd$inat$data[[1]]$longitude))
   expect_false(anyNA(dd$inat$data[[1]]$latitude))
 
@@ -57,7 +53,6 @@ test_that("has_coords works with all data sources as planned", {
 
   expect_true(aa$gbif$meta$opts$hasCoordinate)
   expect_true(bb$ecoengine$meta$opts$georeferenced)
-  expect_true(cc$antweb$meta$opts$georeferenced)
   expect_true(dd$inat$meta$opts$geo)
   expect_equal(ee$idigbio$meta$opts$rq$geopoint$type, "exists")
   expect_true(ff$vertnet$meta$opts$mappable)
